# Analytical solution of thermo-osmosis in 1D column

See [1] for details.

[1] Zhou, Y., Rajapakse, R. K. N. D., & Graham, J. (1998).
International Journal of Solids and Structures, 35(34-35), 4659-4683.


Copyright (c) 2012-2022, OpenGeoSys Community (http://www.opengeosys.org)
            Distributed under a Modified BSD License.
              See accompanying file LICENSE or
              http://www.opengeosys.org/project/license
